pub struct ProfileRouter { /* private fields */ }Expand description
Routes based on a list of named profiles, with one active at a time.
Falls back to Direct when no profile is active.
Implementations